# djvu-viewer
DjVu Viewer and tarball converter

| | |
| :--- | :--- |
| **PyPi** | [![PyPI Status](https://img.shields.io/pypi/v/djvu-viewer.svg)](https://pypi.python.org/pypi/djvu-viewer/) [![License](https://img.shields.io/github/license/WolfgangFahl/djvu-viewer.svg)](https://www.apache.org/licenses/LICENSE-2.0) [![pypi](https://img.shields.io/pypi/pyversions/djvu-viewer)](https://pypi.org/project/djvu-viewer/) [![format](https://img.shields.io/pypi/format/djvu-viewer)](https://pypi.org/project/djvu-viewer/) [![downloads](https://img.shields.io/pypi/dd/djvu-viewer)](https://pypi.org/project/djvu-viewer/) |
| **GitHub** | [![Github Actions Build](https://github.com/WolfgangFahl/djvu-viewer/actions/workflows/build.yml/badge.svg)](https://github.com/WolfgangFahl/djvu-viewer/actions/workflows/build.yml) [![Release](https://img.shields.io/github/v/release/WolfgangFahl/djvu-viewer)](https://github.com/WolfgangFahl/djvu-viewer/releases) [![Contributors](https://img.shields.io/github/contributors/WolfgangFahl/djvu-viewer)](https://github.com/WolfgangFahl/djvu-viewer/graphs/contributors) [![Last Commit](https://img.shields.io/github/last-commit/WolfgangFahl/djvu-viewer)](https://github.com/WolfgangFahl/djvu-viewer/commits/) [![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/djvu-viewer.svg)](https://github.com/WolfgangFahl/djvu-viewer/issues) [![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/djvu-viewer.svg)](https://github.com/WolfgangFahl/djvu-viewer/issues/?q=is%3Aissue+is%3Aclosed) |
| **Code** | [![style-black](https://img.shields.io/badge/%20style-black-000000.svg)](https://github.com/psf/black) [![imports-isort](https://img.shields.io/badge/%20imports-isort-%231674b1)](https://pycqa.github.io/isort/) |
| **Docs** | [![API Docs](https://img.shields.io/badge/API-Documentation-blue)](https://WolfgangFahl.github.io/djvu-viewer/) [![formatter-docformatter](https://img.shields.io/badge/%20formatter-docformatter-fedcba.svg)](https://github.com/PyCQA/docformatter) [![style-google](https://img.shields.io/badge/%20style-google-3666d6.svg)](https://google.github.io/styleguide/pyguide.html#s3.8-comments-and-docstrings) |

# Demo
- [genwik39-demo](https://genwiki39.genealogy.net/djvu-viewer/)

# Documentation
- [DjVu catalog and Viewer](https://wiki.bitplan.com/index.php/djvu-viewer)